.. _finite_cartpole:


Finite Track CartPole: Balance Task
-----------------------------------

.. autoclass:: rlpy.Domains.FiniteTrackCartPole.FiniteCartPoleBalance
    :members:
    :inherited-members:


Finite Track CartPole: Balance Task ("Original") per Sutton + Barto Definition
------------------------------------------------------------------------------

.. autoclass:: rlpy.Domains.FiniteTrackCartPole.FiniteCartPoleBalanceOriginal
    :members:
    :inherited-members:


Finite Track CartPole: Balance Task ("Modern") with 3 (not 2) possible actions
------------------------------------------------------------------------------

.. autoclass:: rlpy.Domains.FiniteTrackCartPole.FiniteCartPoleBalanceModern
    :members:
    :inherited-members:


Finite Track CartPole: Swing-Up Task
------------------------------------

.. autoclass:: rlpy.Domains.FiniteTrackCartPole.FiniteCartPoleSwingUp
    :members:
    :inherited-members:


Finite Track CartPole: Swing-Up Task with Friction
--------------------------------------------------

.. autoclass:: rlpy.Domains.FiniteTrackCartPole.FiniteCartPoleSwingUpFriction
    :members:
    :inherited-members:

